@@ -1,10 +1,10 @@
+from warnings import warn
 from ctypes import c_uint8, c_uint16, c_int32, c_uint32, byref, c_double
 from typing import Dict, Union, Optional
 from enum import IntEnum, unique
 from . import _MPuLib, _check_limits
 from .Nfc import TechnologyType, DataRate
 from .Nfc import VicinityDataRate, VicinitySubCarrier
-from .MPStatus import CTS3ErrorCode
 from .MPException import CTS3Exception
 
 
@@ -29,11 +29,9 @@ def MPC_ChannelOpen(mode: CardEmulationMode =
     if not isinstance(mode, CardEmulationMode):
         raise TypeError('mode must be an instance of '
                         'CardEmulationMode IntEnum')
-    ret = CTS3ErrorCode(_MPuLib.MPC_ChannelOpen(
+    CTS3Exception._check_error(_MPuLib.MPC_ChannelOpen(
         c_uint8(0),
         c_uint8(mode)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 @unique
@@ -57,19 +55,15 @@ def MPC_ChannelFlush(direction: CardEmulationChannelDirection =
     if not isinstance(direction, CardEmulationChannelDirection):
         raise TypeError('direction must be an instance of '
                         'CardEmulationChannelDirection IntEnum')
-    ret = CTS3ErrorCode(_MPuLib.MPC_ChannelFlush(
+    CTS3Exception._check_error(_MPuLib.MPC_ChannelFlush(
         c_uint8(0),
         c_uint8(direction)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 def MPC_ChannelClose() -> None:
     """Closes card emulation"""
-    ret = CTS3ErrorCode(_MPuLib.MPC_ChannelClose(
+    CTS3Exception._check_error(_MPuLib.MPC_ChannelClose(
         c_uint8(0)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 @unique
@@ -91,11 +85,9 @@ def MPC_SelectLoadAntennaNfc(load: NfcLoad) -> None:
     """
     if not isinstance(load, NfcLoad):
         raise TypeError('load must be an instance of NfcLoad IntEnum')
-    ret = CTS3ErrorCode(_MPuLib.MPC_SelectLoadAntennaNfc(
+    CTS3Exception._check_error(_MPuLib.MPC_SelectLoadAntennaNfc(
         c_uint8(0),
         c_uint16(load)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 def MPC_SetLMAForCardEmulation(low_voltage: float,
@@ -113,12 +105,10 @@ def MPC_SetLMAForCardEmulation(low_voltage: float,
     high_voltage_mV = round(high_voltage * 1e3)
     _check_limits(c_int32, low_voltage_mV, 'low_voltage')
     _check_limits(c_int32, high_voltage_mV, 'high_voltage')
-    ret = CTS3ErrorCode(_MPuLib.MPC_SetLMAForCardEmulation(
+    CTS3Exception._check_error(_MPuLib.MPC_SetLMAForCardEmulation(
         c_uint8(0),
         c_int32(low_voltage_mV),
         c_int32(high_voltage_mV)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 def MPC_SetLMAForEMD(low_voltage: float,
@@ -136,12 +126,10 @@ def MPC_SetLMAForEMD(low_voltage: float,
     high_voltage_mV = round(high_voltage * 1e3)
     _check_limits(c_int32, low_voltage_mV, 'low_voltage')
     _check_limits(c_int32, high_voltage_mV, 'high_voltage')
-    ret = CTS3ErrorCode(_MPuLib.MPC_SetLMAForEMD(
+    CTS3Exception._check_error(_MPuLib.MPC_SetLMAForEMD(
         c_uint8(0),
         c_int32(low_voltage_mV),
         c_int32(high_voltage_mV)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 @unique
@@ -155,26 +143,27 @@ class SubcarrierFrequency(IntEnum):
     SubCarrier6780 = 6780
 
 
-def MPC_SetUpReferencePICC(lma_generation: bool,
-                           subcarrier: SubcarrierFrequency) -> None:
+def MPC_SetUpReferencePICC(subcarrier: Optional[SubcarrierFrequency]) -> None:
     """Generates a sub-carrier frequency
 
     Parameters
     ----------
-    lma_generation : bool
-        True to enable generation
     subcarrier : SubcarrierFrequency
-        Sub-carrier frequency
+        Sub-carrier frequency, or None to disable generation
     """
-    if not isinstance(subcarrier, SubcarrierFrequency):
-        raise TypeError('subcarrier must be an instance of '
-                        'SubcarrierFrequency IntEnum')
-    ret = CTS3ErrorCode(_MPuLib.MPC_SetUpReferencePICC(
-        c_uint8(0),
-        c_uint8(1) if lma_generation else c_uint8(0),
-        c_uint32(subcarrier)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
+    if subcarrier is None:
+        CTS3Exception._check_error(_MPuLib.MPC_SetUpReferencePICC(
+            c_uint8(0),
+            c_uint8(0),
+            c_uint32(0)))
+    else:
+        if not isinstance(subcarrier, SubcarrierFrequency):
+            raise TypeError('subcarrier must be an instance of '
+                            'SubcarrierFrequency IntEnum')
+        CTS3Exception._check_error(_MPuLib.MPC_SetUpReferencePICC(
+            c_uint8(0),
+            c_uint8(1),
+            c_uint32(subcarrier)))
 
 
 def MPC_SetPCDPauseMax(pause_duration_fc: float) -> None:
@@ -187,12 +176,10 @@ def MPC_SetPCDPauseMax(pause_duration_fc: float) -> None:
     """
     pause_duration_10fc = round(pause_duration_fc * 10)
     _check_limits(c_uint16, pause_duration_10fc, 'pause_duration_fc')
-    ret = CTS3ErrorCode(_MPuLib.MPC_SetPCDPauseMax(
+    CTS3Exception._check_error(_MPuLib.MPC_SetPCDPauseMax(
         c_uint8(0),
         c_uint8(TechnologyType.TYPE_A),
         c_uint16(pause_duration_10fc)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 def MPC_SetDetectionPCDModulation(ask_filter: int) -> None:
@@ -204,11 +191,9 @@ def MPC_SetDetectionPCDModulation(ask_filter: int) -> None:
         Raw ASK detection filter value
     """
     _check_limits(c_uint32, ask_filter, 'ask_filter')
-    ret = CTS3ErrorCode(_MPuLib.MPC_SetDetectionPCDModulation(
+    CTS3Exception._check_error(_MPuLib.MPC_SetDetectionPCDModulation(
         c_uint8(0),
         c_uint32(ask_filter)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 # region PCD communication
 
@@ -222,16 +207,55 @@ def MPC_RfFieldOffDetected() -> bool:
         True if RF field went off
     """
     field = c_uint32()
-    ret = CTS3ErrorCode(_MPuLib.MPC_RfFieldOffDetected(
+    CTS3Exception._check_error(_MPuLib.MPC_RfFieldOffDetected(
         c_uint8(0),
         byref(field)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
-    return field > 0
+    return field.value > 0
 
 
-def MPC_WaitAndGetFrame(timeout: float) -> Dict[str,
-                                                Union[bytes, TechnologyType]]:
+def MPC_WaitTypeAActiveState(atqa: bytes, uid: bytes,
+                             sak: Union[bytes, int],
+                             timeout: float) -> None:
+    """Waits for Type A activation
+
+    Parameters
+    ----------
+    atqa : bytes
+        2-byte ATQA to answer
+    uid : bytes or int
+        UID to answer
+    sak : bytes
+        SAK byte to answer
+    timeout : float
+        Activation timeout in s
+    """
+    if not isinstance(atqa, bytes) or len(atqa) != 2:
+        raise TypeError('atqa must be an instance of 2 bytes')
+    if not isinstance(uid, bytes):
+        raise TypeError('uid must be an instance of bytes')
+    _check_limits(c_uint32, len(uid), 'uid')
+    if isinstance(sak, bytes):
+        if len(sak) != 1:
+            raise TypeError('sak must be an instance of 1 byte')
+        sak_value = sak[0]
+    elif isinstance(sak, int):
+        _check_limits(c_uint8, sak, 'sak')
+        sak_value = sak
+    else:
+        raise TypeError('sak must be an instance of int or 1 byte')
+    timeout_ms = round(timeout * 1e3)
+    _check_limits(c_uint32, timeout_ms, 'timeout')
+    CTS3Exception._check_error(_MPuLib.MPC_WaitTypeAActiveState(
+        c_uint8(0),
+        atqa,
+        uid,
+        c_uint32(len(uid)),
+        byref(c_uint8(sak_value)),
+        c_uint32(timeout_ms)))
+
+
+def MPC_WaitAndGetFrame(timeout: float) \
+        -> Dict[str, Union[bytes, TechnologyType]]:
     """Waits for an incoming frame
 
     Parameters
@@ -242,8 +266,8 @@ def MPC_WaitAndGetFrame(timeout: float) -> Dict[str,
     Returns
     -------
     dict
-        'rx_frame' (bytes): Received frame
-        'rx_type' (TechnologyType): Received frame type
+        'rx_frame' (bytes) : Received frame
+        'rx_type' (TechnologyType) : Received frame type
     """
     timeout_ms = round(timeout * 1e3)
     _check_limits(c_uint32, timeout_ms, 'timeout')
@@ -251,22 +275,19 @@ def MPC_WaitAndGetFrame(timeout: float) -> Dict[str,
     data = bytes(max_size)
     card_type = c_int32()
     bytes_number = c_uint32()
-    ret = CTS3ErrorCode(_MPuLib.MPC_WaitAndGetFrame(
+    CTS3Exception._check_error(_MPuLib.MPC_WaitAndGetFrame(
         c_uint8(0),
         c_uint32(timeout_ms),
         byref(card_type),
         data,
         c_uint32(max_size),
         byref(bytes_number)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     return {'rx_frame': data[:bytes_number.value],
             'rx_type': TechnologyType(card_type.value)}
 
 
-def MPC_WaitAndGetFrameTypeA106ModeBit(timeout: float) -> Dict[str,
-                                                               Union[bytes,
-                                                                     int]]:
+def MPC_WaitAndGetFrameTypeA106ModeBit(timeout: float) \
+        -> Dict[str, Union[bytes, int]]:
     """Waits for a Type A 106kb/s incoming frame
 
     Parameters
@@ -277,26 +298,24 @@ def MPC_WaitAndGetFrameTypeA106ModeBit(timeout: float) -> Dict[str,
     Returns
     -------
     dict
-        'rx_frame' (bytes): Received frame
-        'rx_bits_number' (int): Number of received bits
+        'rx_frame' (bytes) : Received frame
+        'rx_bits_number' (int) : Number of received bits
     """
     timeout_ms = round(timeout * 1e3)
     _check_limits(c_uint32, timeout_ms, 'timeout')
     max_size = 8192
     data = bytes(max_size)
     rx_bits = c_uint32()
-    ret = CTS3ErrorCode(_MPuLib.MPC_WaitAndGetFrameTypeA106ModeBit(
+    CTS3Exception._check_error(_MPuLib.MPC_WaitAndGetFrameTypeA106ModeBit(
         c_uint8(0),
         c_uint32(timeout_ms),
         data,
         c_uint32(max_size),
         byref(rx_bits)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     bytes_number = int(rx_bits.value / 8)
     if rx_bits.value % 8 > 0:
         bytes_number += 1
-    return {'rx_frame': data[:bytes_number.value],
+    return {'rx_frame': data[:bytes_number],
             'rx_bits_number': rx_bits.value}
 
 
@@ -316,13 +335,11 @@ def MPC_SendRawFrameType(card_type: TechnologyType, frame: bytes) -> None:
     if not isinstance(frame, bytes):
         raise TypeError('frame must be an instance of bytes')
     _check_limits(c_uint32, len(frame), 'frame')
-    ret = CTS3ErrorCode(_MPuLib.MPC_SendRawFrameType(
+    CTS3Exception._check_error(_MPuLib.MPC_SendRawFrameType(
         c_uint8(0),
         c_uint32(card_type),
         frame,
         c_uint32(len(frame))))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 def MPC_SendRawFrameTypeWithCRC(card_type: TechnologyType,
@@ -342,13 +359,11 @@ def MPC_SendRawFrameTypeWithCRC(card_type: TechnologyType,
     if not isinstance(frame, bytes):
         raise TypeError('frame must be an instance of bytes')
     _check_limits(c_uint32, len(frame), 'frame')
-    ret = CTS3ErrorCode(_MPuLib.MPC_SendRawFrameTypeWithCRC(
+    CTS3Exception._check_error(_MPuLib.MPC_SendRawFrameTypeWithCRC(
         c_uint8(0),
         c_uint32(card_type),
         frame,
         c_uint32(len(frame))))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 def MPC_TransmitFrameA(frame: bytes, bits_number: Optional[int] = None,
@@ -360,7 +375,7 @@ def MPC_TransmitFrameA(frame: bytes, bits_number: Optional[int] = None,
     frame : bytes
         Frame to transmit
     bits_number : int, optional
-        Number of bits to transmit
+        Number of bits to transmit (8 × frame length if None)
     parity : bool, optional
         True to include parity bit
     """
@@ -369,39 +384,42 @@ def MPC_TransmitFrameA(frame: bytes, bits_number: Optional[int] = None,
     if bits_number is None:
         bits_number = 8 * len(frame)
     _check_limits(c_uint32, bits_number, 'bits_number')
-    ret = CTS3ErrorCode(_MPuLib.MPC_TransmitFrameA(
+    CTS3Exception._check_error(_MPuLib.MPC_TransmitFrameA(
         c_uint8(0),
         frame,
         c_uint32(bits_number),
         c_int32(1) if parity else c_int32(0)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
-def MPS_SimSetDesyncPattern(enable: bool, t1_fc: Optional[float] = None,
-                            t2_fc: Optional[float] = None) -> None:
+def MPS_SimSetDesyncPattern(t1_fc: Optional[float],
+                            t2_fc: Optional[float]) -> None:
     """Enables NFC Desync Pattern for following FeliCa frames
 
     Parameters
     ----------
-    enable : bool
-        True to enable Desync Pattern
     t1_fc : float
         t1 pattern duration in carrier periods
+        (None to deactivate Desync Pattern)
     t2_fc : float
         t2 pattern duration in carrier periods
+        (None to deactivate Desync Pattern)
     """
-    t1_10fc = t1_fc * 1e1 if t1_fc else 0
-    _check_limits(c_uint32, t1_10fc, 't1_fc')
-    t2_10fc = t2_fc * 1e1 if t2_fc else 0
-    _check_limits(c_uint32, t2_10fc, 't2_fc')
-    ret = CTS3ErrorCode(_MPuLib.MPS_SimSetDesyncPattern(
-        c_uint8(0),
-        c_uint8(1) if enable else c_uint8(0),
-        c_uint32(t1_10fc),
-        c_uint32(t2_10fc)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
+    if t1_fc and t2_fc:
+        t1_10fc = round(t1_fc * 1e1)
+        _check_limits(c_uint32, t1_10fc, 't1_fc')
+        t2_10fc = round(t2_fc * 1e1)
+        _check_limits(c_uint32, t2_10fc, 't2_fc')
+        CTS3Exception._check_error(_MPuLib.MPS_SimSetDesyncPattern(
+            c_uint8(0),
+            c_uint8(1),
+            c_uint32(t1_10fc),
+            c_uint32(t2_10fc)))
+    else:
+        CTS3Exception._check_error(_MPuLib.MPS_SimSetDesyncPattern(
+            c_uint8(0),
+            c_uint8(0),
+            c_uint32(0),
+            c_uint32(0)))
 
 
 def MPS_SimChangeDataRate(picc_datarate: DataRate,
@@ -421,12 +439,10 @@ def MPS_SimChangeDataRate(picc_datarate: DataRate,
     if not isinstance(pcd_datarate, DataRate):
         raise TypeError('pcd_datarate must be an instance of '
                         'DataRate IntEnum')
-    ret = CTS3ErrorCode(_MPuLib.MPS_SimChangeDataRate(
+    CTS3Exception._check_error(_MPuLib.MPS_SimChangeDataRate(
         c_uint8(0),
         c_uint16(picc_datarate),
         c_uint16(pcd_datarate)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 def MPC_SelectVICCDataRate(data_rate: VicinityDataRate,
@@ -446,12 +462,23 @@ def MPC_SelectVICCDataRate(data_rate: VicinityDataRate,
     if not isinstance(sub_carrier, VicinitySubCarrier):
         raise TypeError('sub_carrier must be an instance of '
                         'VicinitySubCarrier IntEnum')
-    ret = CTS3ErrorCode(_MPuLib.MPC_SelectVICCDataRate(
+    CTS3Exception._check_error(_MPuLib.MPC_SelectVICCDataRate(
         c_uint8(0),
         c_uint8(data_rate),
         c_uint8(sub_carrier)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
+
+
+def MPS_SimVicinityEofMode(enabled: bool) -> None:
+    """Enables Vicinity isolated EOF reception mode
+
+    Parameters
+    ----------
+    enabled : bool
+        True to enable isolated EOF mode
+    """
+    CTS3Exception._check_error(_MPuLib.MPS_SimVicinityEofMode(
+        c_uint8(0),
+        c_uint32(1) if enabled else c_uint32(0)))
 
 
 def MPS_SimSetFdt(fdt1_clk: int, fdt2_clk: int) -> None:
@@ -466,25 +493,21 @@ def MPS_SimSetFdt(fdt1_clk: int, fdt2_clk: int) -> None:
     """
     _check_limits(c_uint32, fdt1_clk, 'fdt1_clk')
     _check_limits(c_uint32, fdt2_clk, 'fdt2_clk')
-    ret = CTS3ErrorCode(_MPuLib.MPS_SimSetFdt(
+    CTS3Exception._check_error(_MPuLib.MPS_SimSetFdt(
         c_uint8(0),
         c_uint8(0),
         c_uint32(fdt1_clk),
         c_uint32(fdt2_clk)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 # endregion
 
 # region IQ Load Modulation
 
 
-def MPC_IQLoadModulationInit() -> None:
+def MPC_IQLMInit() -> None:
     """Initializes IQ load modulation"""
-    ret = CTS3ErrorCode(_MPuLib.MPC_IQLoadModulationInit(
+    CTS3Exception._check_error(_MPuLib.MPC_IQLMInit(
         c_uint8(0)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 @unique
@@ -494,21 +517,47 @@ class IqlmMode(IntEnum):
     IQLM_MODE_SETUP = 1
 
 
-def MPC_IQLoadModulationStart(mode: IqlmMode) -> None:
+def MPC_IQLMStart(mode: IqlmMode = IqlmMode.IQLM_MODE_DYNAMIC) -> None:
     """Starts IQ load modulation regulation
 
     Parameters
     ----------
-    mode : IqlmMode
+    mode : IqlmMode, optional
         Regulation mode
     """
     if not isinstance(mode, IqlmMode):
         raise TypeError('mode must be an instance of IqlmMode IntEnum')
-    ret = CTS3ErrorCode(_MPuLib.MPC_IQLoadModulationStart(
+    CTS3Exception._check_error(_MPuLib.MPC_IQLMStart(
         c_uint8(0),
         c_uint8(mode)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
+
+
+def MPC_IQLoadModulationStart(mode: IqlmMode = IqlmMode.IQLM_MODE_DYNAMIC) \
+        -> None:
+    """Starts IQ load modulation regulation
+
+    Parameters
+    ----------
+    mode : IqlmMode, optional
+        Regulation mode
+    """
+    warn('MPC_IQLoadModulationStart renamed as MPC_IQLMStart',
+         FutureWarning, 2)
+    return MPC_IQLMStart(mode)
+
+
+def MPC_IQLMSuspendControlLoop(suspend: bool) -> None:
+    """Suspends IQ load modulation regulation
+
+    Parameters
+    ----------
+    suspend : bool
+        True to suspend the regulation
+    """
+    CTS3Exception._check_error(_MPuLib.MPC_IQLMSuspendControlLoop(
+        c_uint8(0),
+        c_uint8(1) if suspend else c_uint8(0),
+        c_uint32(0)))
 
 
 def MPC_IQLoadModulationSuspendControlLoop(suspend: bool) -> None:
@@ -519,23 +568,26 @@ def MPC_IQLoadModulationSuspendControlLoop(suspend: bool) -> None:
     suspend : bool
         True to suspend the regulation
     """
-    ret = CTS3ErrorCode(_MPuLib.MPC_IQLoadModulationSuspendControlLoop(
-        c_uint8(0),
-        c_uint8(1) if suspend else c_uint8(0),
-        c_uint32(0)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
+    warn('MPC_IQLoadModulationSuspendControlLoop renamed as '
+         'MPC_IQLMSuspendControlLoop',
+         FutureWarning, 2)
+    return MPC_IQLMSuspendControlLoop(suspend)
+
+
+def MPC_IQLMStop() -> None:
+    """Stops IQ load modulation regulation"""
+    CTS3Exception._check_error(_MPuLib.MPC_IQLMStop(
+        c_uint8(0)))
 
 
 def MPC_IQLoadModulationStop() -> None:
     """Stops IQ load modulation regulation"""
-    ret = CTS3ErrorCode(_MPuLib.MPC_IQLoadModulationStop(
-        c_uint8(0)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
+    warn('MPC_IQLoadModulationStop renamed as MPC_IQLMStop',
+         FutureWarning, 2)
+    return MPC_IQLMStop()
 
 
-def MPC_IQLoadModulationSetHR(amplitude: float, phase: float) -> None:
+def MPC_IQLMSetHR(amplitude: float, phase: float) -> None:
     """Sets loading effect
 
     Parameters
@@ -549,52 +601,87 @@ def MPC_IQLoadModulationSetHR(amplitude: float, phase: float) -> None:
     _check_limits(c_uint32, amplitude_mV, 'amplitude')
     phase_cdeg = round(phase * 1e2)
     _check_limits(c_int32, phase_cdeg, 'phase')
-    ret = CTS3ErrorCode(_MPuLib.MPC_IQLoadModulationSetHR(
+    CTS3Exception._check_error(_MPuLib.MPC_IQLMSetHR(
         c_uint8(0),
         c_uint32(amplitude_mV),
         c_int32(phase_cdeg),
         c_uint32(0)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
-def MPC_IQLoadModulationSidebands(amplitude_sb1: float, phase_sb1: float,
-                                  amplitude_sb2: float, phase_sb2: float,
+def MPC_IQLoadModulationSetHR(amplitude: float, phase: float) -> None:
+    """Sets loading effect
+
+    Parameters
+    ----------
+    amplitude : float
+        Loading effect amplitude in Vpp
+    phase : float
+        Loading effect phase in °
+    """
+    warn('MPC_IQLoadModulationSetHR renamed as MPC_IQLMSetHR',
+         FutureWarning, 2)
+    return MPC_IQLMSetHR(amplitude, phase)
+
+
+def MPC_IQLMSidebands(lower_amplitude: float, lower_phase: float,
+                      upper_amplitude: float, upper_phase: float,
+                      offset: float) -> None:
+    """Sets side bands
+
+    Parameters
+    ----------
+    lower_amplitude : float
+        Lower side-band amplitude in Vpp
+    lower_phase : float
+        Lower side-band phase in °
+    upper_amplitude : float
+        Upper side-band amplitude in Vpp
+    upper_phase : float
+        Upper side-band phase in °
+    offset : float
+        Modulation offset in Vpp
+    """
+    lower_amplitude_mV = round(lower_amplitude * 1e3)
+    _check_limits(c_uint32, lower_amplitude_mV, 'lower_amplitude')
+    lower_phase_cdeg = round(lower_phase * 1e2)
+    _check_limits(c_int32, lower_phase_cdeg, 'lower_phase')
+    upper_amplitude_mV = round(upper_amplitude * 1e3)
+    _check_limits(c_uint32, upper_amplitude_mV, 'upper_amplitude')
+    upper_phase_cdeg = round(upper_phase * 1e2)
+    _check_limits(c_int32, upper_phase_cdeg, 'upper_phase')
+    offset_mV = round(offset * 1e3)
+    _check_limits(c_int32, offset_mV, 'offset')
+    CTS3Exception._check_error(_MPuLib.MPC_IQLMSidebands(
+        c_uint8(0),
+        c_uint32(lower_amplitude_mV),
+        c_int32(lower_phase_cdeg),
+        c_uint32(upper_amplitude_mV),
+        c_int32(upper_phase_cdeg),
+        c_int32(offset_mV)))
+
+
+def MPC_IQLoadModulationSidebands(lower_amplitude: float, lower_phase: float,
+                                  upper_amplitude: float, upper_phase: float,
                                   offset: float) -> None:
     """Sets side bands
 
     Parameters
     ----------
-    amplitude_sb1 : float
-        First side band amplitude in Vpp
-    phase_sb1 : float
-        First side band phase in °
-    amplitude_sb2 : float
-        Second side band amplitude in Vpp
-    phase_sb2 : float
-        Second side band phase in °
+    lower_amplitude : float
+        Lower side-band amplitude in Vpp
+    lower_phase : float
+        Lower side-band phase in °
+    upper_amplitude : float
+        Upper side-band amplitude in Vpp
+    upper_phase : float
+        Upper side-band phase in °
     offset : float
         Modulation offset in Vpp
     """
-    amplitude_sb1_mV = round(amplitude_sb1 * 1e3)
-    _check_limits(c_uint32, amplitude_sb1_mV, 'amplitude_sb1')
-    phase_sb1_cdeg = round(phase_sb1 * 1e2)
-    _check_limits(c_int32, phase_sb1_cdeg, 'phase_sb1')
-    amplitude_sb2_mV = round(amplitude_sb2 * 1e3)
-    _check_limits(c_uint32, amplitude_sb2_mV, 'amplitude_sb2')
-    phase_sb2_cdeg = round(phase_sb2 * 1e2)
-    _check_limits(c_int32, phase_sb2_cdeg, 'phase_sb2')
-    offset_mV = round(offset * 1e3)
-    _check_limits(c_int32, offset_mV, 'offset')
-    ret = CTS3ErrorCode(_MPuLib.MPC_IQLoadModulationSidebands(
-        c_uint8(0),
-        c_uint32(amplitude_sb1_mV),
-        c_int32(phase_sb1_cdeg),
-        c_uint32(amplitude_sb2_mV),
-        c_int32(phase_sb2_cdeg),
-        c_int32(offset_mV)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
+    warn('MPC_IQLoadModulationSidebands renamed as MPC_IQLMSidebands',
+         FutureWarning, 2)
+    return MPC_IQLMSidebands(lower_amplitude, lower_phase,
+                             upper_amplitude, upper_phase, offset)
 
 
 @unique
@@ -607,6 +694,32 @@ class IqlmParameter(IntEnum):
     CP_IQLM_MODULATION_INHIBIT = 7
 
 
+def MPC_IQLMChangeParameters(parameter: IqlmParameter,
+                             value: Union[float, bool]) -> None:
+    """Changes IQ load modulation regulation parameter
+
+    Parameters
+    ----------
+    parameter : IqlmParameter
+        Parameter type
+    value : float or bool
+        Parameter value
+    """
+    if not isinstance(parameter, IqlmParameter):
+        raise TypeError('parameter must be an instance of '
+                        'IqlmParameter IntEnum')
+    if parameter == IqlmParameter.CP_IQLM_REF_CARRIER_PHASE:  # 1°/100
+        val = round(value * 1e2)
+        _check_limits(c_int32, val, 'value')
+    else:  # boolean
+        val = 1 if value else 0
+    CTS3Exception._check_error(_MPuLib.MPC_IQLMChangeParameters(
+        c_uint8(0),
+        c_uint8(parameter),
+        c_int32(val),
+        c_uint32(0)))
+
+
 def MPC_IQLoadModulationChangeParameters(parameter: IqlmParameter,
                                          value: Union[float, bool]) -> None:
     """Changes IQ load modulation regulation parameter
@@ -618,21 +731,10 @@ def MPC_IQLoadModulationChangeParameters(parameter: IqlmParameter,
     value : float or bool
         Parameter value
     """
-    if not isinstance(parameter, IqlmParameter):
-        raise TypeError('parameter must be an instance of '
-                        'IqlmParameter IntEnum')
-    if parameter == IqlmParameter.CP_IQLM_REF_CARRIER_PHASE:  # 1/100 degree
-        val = round(value * 1e2)
-        _check_limits(c_int32, val, 'value')
-    else:  # boolean
-        val = 1 if value else 0
-    ret = CTS3ErrorCode(_MPuLib.MPC_IQLoadModulationChangeParameters(
-        c_uint8(0),
-        c_uint8(parameter),
-        c_int32(val),
-        c_uint32(0)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
+    warn('MPC_IQLoadModulationChangeParameters renamed as '
+         'MPC_IQLMChangeParameters',
+         FutureWarning, 2)
+    return MPC_IQLMChangeParameters(parameter, value)
 
 
 @unique
@@ -647,9 +749,8 @@ class IqlmCondition(IntEnum):
     IQLM_PHASE_DRIFT_CONDITION_B2 = 6
 
 
-def MPC_IQLoadModulationPhaseDrift(frequency_drift: float,
-                                   condition: IqlmCondition,
-                                   data_rate: DataRate) -> None:
+def MPC_IQLMPhaseDrift(frequency_drift: float, condition: IqlmCondition,
+                       data_rate: DataRate) -> None:
     """Selects phase drift
 
     Parameters
@@ -668,13 +769,30 @@ def MPC_IQLoadModulationPhaseDrift(frequency_drift: float,
                         'IqlmCondition IntEnum')
     if not isinstance(data_rate, DataRate):
         raise TypeError('data_rate must be an instance of DataRate IntEnum')
-    ret = CTS3ErrorCode(_MPuLib.MPC_IQLoadModulationPhaseDrift(
+    CTS3Exception._check_error(_MPuLib.MPC_IQLMPhaseDrift(
         c_uint8(0),
         c_uint32(frequency_drift_Hz),
         c_int32(condition),
         data_rate))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
+
+
+def MPC_IQLoadModulationPhaseDrift(frequency_drift: float,
+                                   condition: IqlmCondition,
+                                   data_rate: DataRate) -> None:
+    """Selects phase drift
+
+    Parameters
+    ----------
+    frequency_drift : float
+        Frequency drift in Hz
+    condition : IqlmCondition
+        Phase drift condition
+    data_rate : DataRate
+        Phase drift data rate
+    """
+    warn('MPC_IQLoadModulationPhaseDrift renamed as MPC_IQLMPhaseDrift',
+         FutureWarning, 2)
+    return MPC_IQLMPhaseDrift(frequency_drift, condition, data_rate,)
 
 
 @unique
@@ -683,28 +801,40 @@ class IqlmPhaseStatus(IntEnum):
     IQLM_PHASE_TRACKING_OFF = 0
     IQLM_COARSE_FREQUENCY_TRACKING = 1
     IQLM_FINE_PHASE_TRACKING = 2
-    IQLM_PHASE_LOCKED = 3
+    IQLM_PHASE_LOCKED = 4
 
 
-def MPC_IQLoadModulationGetStatus() -> Dict[str,
-                                            Union[IqlmPhaseStatus, float]]:
+def MPC_IQLMGetStatus() -> Dict[str, Union[IqlmPhaseStatus, float]]:
     """Gets IQ load modulation regulation status
 
     Returns
     -------
     dict
-        'status' (IqlmPhaseStatus): Regulation loop status
-        'frequency' (float): Regulation frequency in Hz
+        'status' (IqlmPhaseStatus) : Regulation loop status
+        'frequency' (float) : Regulation frequency in Hz
     """
     status = c_uint8()
     freq = c_double()
-    ret = CTS3ErrorCode(_MPuLib.MPC_IQLoadModulationGetStatus(
+    CTS3Exception._check_error(_MPuLib.MPC_IQLMGetStatus(
         c_uint8(0),
         byref(status),
         byref(freq)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     return {'status': IqlmPhaseStatus(status.value),
             'frequency': freq.value}
 
+
+def MPC_IQLoadModulationGetStatus() \
+        -> Dict[str, Union[IqlmPhaseStatus, float]]:
+    """Gets IQ load modulation regulation status
+
+    Returns
+    -------
+    dict
+        'status' (IqlmPhaseStatus) : Regulation loop status
+        'frequency' (float) : Regulation frequency in Hz
+    """
+    warn('MPC_IQLoadModulationGetStatus renamed as MPC_IQLMGetStatus',
+         FutureWarning, 2)
+    return MPC_IQLMGetStatus()
+
 # endregion
