@@ -1,11 +1,12 @@
 from ctypes import c_uint8, c_uint16, c_int32, c_uint32, c_double, byref
-from ctypes import c_void_p, cast, POINTER, create_string_buffer
-from typing import List, Optional, Dict, Union
+from ctypes import c_void_p, POINTER, create_string_buffer, cast as c_cast
+from typing import List, Optional, Dict, Union, overload
 from enum import IntEnum, IntFlag, unique
 from . import _MPuLib, _check_limits
 from .MPStatus import CTS3ErrorCode
 from .MPException import CTS3Exception
 from .Nfc import TechnologyType, NfcUnit, _unit_autoselect, DataRate
+from warnings import warn
 
 
 @unique
@@ -15,14 +16,15 @@ class VdcRange(IntEnum):
     VDC_RANGE_12V = 1
 
 
-def MPC_GetVDCIn(duration: float, voltmeter_range: VdcRange) -> float:
-    """Performs a maximum voltage measurement on the AUX 1 connector
+def MPC_GetVDCIn(duration: float,
+                 voltmeter_range: VdcRange = VdcRange.VDC_RANGE_24V) -> float:
+    """Performs a maximum voltage measurement on AUX 1 or VDC IN connector
 
     Parameters
     ----------
     duration : float
         Measurement duration in s
-    voltmeter_range : VdcRange
+    voltmeter_range : VdcRange, optional
         Voltage measurement range
 
     Returns
@@ -36,19 +38,17 @@ def MPC_GetVDCIn(duration: float, voltmeter_range: VdcRange) -> float:
         raise TypeError('voltmeter_range must be an instance of '
                         'VdcRange IntEnum')
     vdc = c_int32()
-    ret = CTS3ErrorCode(_MPuLib.MPC_GetVDCIn(
+    CTS3Exception._check_error(_MPuLib.MPC_GetVDCIn(
         c_uint8(0),
         byref(vdc),
         c_uint32(duration_ms),
         c_uint32(voltmeter_range)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     return vdc.value / 1e3
 
 
 def MPC_GetVOV(integration_time: float, timeout: float,
-               voltmeter_range: VdcRange) -> float:
-    """Performs an integrated voltage measurement on the AUX 1 connector
+               voltmeter_range: VdcRange = VdcRange.VDC_RANGE_24V) -> float:
+    """Performs an integrated voltage measurement on AUX 1 or VDC IN connector
 
     Parameters
     ----------
@@ -56,7 +56,7 @@ def MPC_GetVOV(integration_time: float, timeout: float,
         Integration time in s
     timeout : float
         Measurement timeout in s
-    voltmeter_range : VdcRange
+    voltmeter_range : VdcRange, optional
         Voltage measurement range
 
     Returns
@@ -72,14 +72,12 @@ def MPC_GetVOV(integration_time: float, timeout: float,
         raise TypeError('voltmeter_range must be an instance of '
                         'VdcRange IntEnum')
     vdc = c_int32()
-    ret = CTS3ErrorCode(_MPuLib.MPC_GetVOV(
+    CTS3Exception._check_error(_MPuLib.MPC_GetVOV(
         c_uint8(0),
         byref(vdc),
         c_uint32(integration_time_us),
         c_uint32(timeout_ms),
         c_uint32(voltmeter_range)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     return vdc.value / 1e3
 
 
@@ -99,6 +97,7 @@ class MeasureSource(IntEnum):
     MEAS_SOURCE_DEMODULATED = 2
     MEAS_SOURCE_VDC_12V = 3
     MEAS_SOURCE_VDC_24V = 4
+    MEAS_SOURCE_PHASE = 5
 
 
 def MPC_StartRFMeasure2(settings: MeasureTriggerSetting, source: MeasureSource,
@@ -128,19 +127,12 @@ def MPC_StartRFMeasure2(settings: MeasureTriggerSetting, source: MeasureSource,
         raise TypeError('source must be an instance of MeasureSource IntEnum')
     if not isinstance(unit, NfcUnit):
         raise TypeError('unit must be an instance of NfcUnit IntEnum')
-    if unit > NfcUnit.UNIT_NS:
-        computed_unit = unit
-        computed_delay = round(delay)
-        computed_duration = round(duration)
-    else:
-        # Unit auto-selection
-        computed_unit, [computed_delay,
-                        computed_duration] = _unit_autoselect(unit,
-                                                              [delay,
-                                                               duration])
+    # Unit auto-selection
+    computed_unit, [computed_delay, computed_duration] = \
+        _unit_autoselect(unit, [delay, duration])
     _check_limits(c_int32, computed_delay, 'delay')
     _check_limits(c_uint32, computed_duration, 'duration')
-    ret = CTS3ErrorCode(_MPuLib.MPC_StartRFMeasure2(
+    CTS3Exception._check_error(_MPuLib.MPC_StartRFMeasure2(
         c_uint8(0),
         c_uint32(settings),
         c_uint32(source),
@@ -148,8 +140,6 @@ def MPC_StartRFMeasure2(settings: MeasureTriggerSetting, source: MeasureSource,
         c_int32(computed_delay),
         c_uint32(computed_duration),
         file_name.encode('ascii')))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 @unique
@@ -173,11 +163,9 @@ def MPC_RFMeasureStatus() -> RfStatus:
         Current trigger status
     """
     status = c_uint8()
-    ret = CTS3ErrorCode(_MPuLib.MPC_RFMeasureStatus(
+    CTS3Exception._check_error(_MPuLib.MPC_RFMeasureStatus(
         c_uint8(0),
         byref(status)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     return RfStatus(status.value)
 
 
@@ -190,7 +178,7 @@ class MeasurementConnector(IntEnum):
 
 
 def MPC_SwitchResonanceFrequencyConnector(connector: MeasurementConnector) \
-                                          -> None:
+        -> None:
     """Changes the connector currently selected to perform a measurement
 
     Parameters
@@ -201,11 +189,9 @@ def MPC_SwitchResonanceFrequencyConnector(connector: MeasurementConnector) \
     if not isinstance(connector, MeasurementConnector):
         raise TypeError('connector must be an instance of '
                         'MeasurementConnector IntEnum')
-    ret = CTS3ErrorCode(_MPuLib.MPC_SwitchResonanceFrequencyConnector(
+    CTS3Exception._check_error(_MPuLib.MPC_SwitchResonanceFrequencyConnector(
         c_uint8(0),
         c_uint8(connector)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 @unique
@@ -230,11 +216,9 @@ def MPC_SelectVoltmeterRange(voltmeter_range: VoltmeterRange) -> None:
     if not isinstance(voltmeter_range, VoltmeterRange):
         raise TypeError('voltmeter_range must be an instance of '
                         'VoltmeterRange IntEnum')
-    ret = CTS3ErrorCode(_MPuLib.MPC_SelectVoltmeterRange(
+    CTS3Exception._check_error(_MPuLib.MPC_SelectVoltmeterRange(
         c_uint8(0),
         c_uint16(voltmeter_range)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 def MPC_GetVoltmeterRange() -> VoltmeterRange:
@@ -246,11 +230,9 @@ def MPC_GetVoltmeterRange() -> VoltmeterRange:
         Voltmeter range
     """
     voltmeter_range = c_uint16()
-    ret = CTS3ErrorCode(_MPuLib.MPC_GetVoltmeterRange(
+    CTS3Exception._check_error(_MPuLib.MPC_GetVoltmeterRange(
         c_uint8(0),
         byref(voltmeter_range)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     return VoltmeterRange(voltmeter_range.value)
 
 
@@ -267,9 +249,7 @@ def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
                                       card_type: TechnologyType,
                                       data_rate: DataRate,
                                       path: Optional[str] = None) \
-                                      -> Dict[str, Union[float,
-                                                         bool,
-                                                         List[float]]]:
+        -> Dict[str, Union[float, bool, List[float]]]:
     """Analyzes analog measurements started with MPC_StartRFMeasure2
     and stores the results in a waveform file
 
@@ -288,54 +268,40 @@ def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
     -------
     dict
         If measurement_type is SCINFC_MEASTYPE_PCD_WAVEFORM:
-            't1' (float): T1 in s (Type A and Vicinity only)
-            't2' (float): T2 in s (Type A 106kb/s and Vicinity only)
-            't3' (float): T3 in s (Type A 106kb/s and Vicinity only)
-            't4' (float): T4 in s (Type A 106kb/s and Vicinity only)
-            't5' (float): T5 in s (Type A > 106kb/s only)
-            't5' (list(float)): T5 list in s (Type A 106kb/s only)
-            't6' (float): T6 in s (Type A > 106kb/s only)
-            'v1' (float): V1 in V
-            'v1_noise_floor' (float): V1 noise floor in V
-                                      (Type B, FeliCa and Vicinity only)
-            'v2' (float): V2 in V
-            'v2_noise_floor' (float): V2 noise floor in V
-                                      (Type B and FeliCa only)
-            'v3' (float): V3 in V
-            'v4' (float): V4 in V
-            'v5' (float): V5 in V (Type A > 106kb/s only)
-            'modulation_index' (float): Modulation index in V
-            'modulation_depth' (float): Modulation depth in V
-                                        (Type A 106kb/s, Type B, FeliCa and
-                                        Vicinity only)
-            'monotonic_rising_edge' (bool): True if rising edge is monotonic
-            'rising_time' (float): Rising time in s
-                                   (Type A > 106kb/s, Type B and FeliCa only)
-            'overshoot_after_rising_edge' (float): Rising edge overshoot in V
-            'undershoot_after_rising_edge' (float): Rising edge undershoot in V
-                                                    (Type A > 106kb/s, Type B
-                                                    and FeliCa only)
-            'ringing_level' (float): Ringing in V (Type A 106kb/s only)
-            'high_state_noise_floor' (float): High state noise in V
-                                              (Type A only)
-            'monotonic_falling_edge' (bool): True if falling edge is monotonic
-            'falling_time' (float): Falling time in s
-                                    (Type A > 106kb/s, Type B and FeliCa only)
-            'overshoot_after_falling_edge' (float): Falling edge overshoot in V
-            'overshoot_delay_after_falling_edge' (float): Delay adter falling
-                                                          edge in s
-                                                          (Type A and
-                                                          Vicinity only)
-            'undershoot_after_falling_edge' (float): Falling edge undershoot
-                                                     in V (Type B and
-                                                     FeliCa only)
+            't1' (float) : T1 in s (Type A and Vicinity only)
+            't2' (float) : T2 in s (Type A 106kb/s and Vicinity only)
+            't3' (float) : T3 in s (Type A 106kb/s and Vicinity only)
+            't4' (float) : T4 in s (Type A 106kb/s and Vicinity only)
+            't5' (float) : T5 in s (Type A > 106kb/s only)
+            't5' (list(float)) : T5 list in s (Type A 106kb/s only)
+            't6' (float) : T6 in s (Type A > 106kb/s only)
+            'v1' (float) : V1 in V
+            'v1_noise_floor' (float) : V1 noise floor in V (Type B, FeliCa and Vicinity only)
+            'v2' (float) : V2 in V
+            'v2_noise_floor' (float) : V2 noise floor in V (Type B and FeliCa only)
+            'v3' (float) : V3 in V
+            'v4' (float) : V4 in V
+            'v5' (float) : V5 in V (Type A > 106kb/s only)
+            'modulation_index' (float) : Modulation index in V
+            'modulation_depth' (float) : Modulation depth in V (Type A 106kb/s, Type B, FeliCa and Vicinity only)
+            'monotonic_rising_edge' (bool) : True if rising edge is monotonic
+            'rising_time' (float) : Rising time in s (Type A > 106kb/s, Type B and FeliCa only)
+            'overshoot_after_rising_edge' (float) : Rising edge overshoot in V
+            'undershoot_after_rising_edge' (float) : Rising edge undershoot in V (Type A > 106kb/s, Type B and FeliCa only)
+            'ringing_level' (float) : Ringing in V (Type A 106kb/s only)
+            'high_state_noise_floor' (float) : High state noise in V (Type A only)
+            'monotonic_falling_edge' (bool) : True if falling edge is monotonic
+            'falling_time' (float) : Falling time in s (Type A > 106kb/s, Type B and FeliCa only)
+            'overshoot_after_falling_edge' (float) : Falling edge overshoot in V
+            'overshoot_delay_after_falling_edge' (float) : Delay adter falling edge in s (Type A and Vicinity only)
+            'undershoot_after_falling_edge' (float) : Falling edge undershoot in V (Type B and FeliCa only)
 
         If measurement_type is SCINFC_MEASTYPE_PICC_LMA:
-            'lma' (float): LMA in V
+            'lma' (float) : LMA in V
 
         If measurement_type is SCINFC_MEASTYPE_PCD_FIELD_STRENGTH:
-            'field_strength' (float): Field strength in Vpp
-    """
+            'field_strength' (float) : Field strength in Vpp
+    """  # noqa: E501
     if not isinstance(measurement_type, MeasurementType):
         raise TypeError('measurement_type must be an instance of '
                         'MeasurementType IntEnum')
@@ -347,7 +313,7 @@ def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
     measurement_count = c_uint32()
     measurements = c_void_p()
     if path:
-        ret = CTS3ErrorCode(_MPuLib.GetAnalyzedMeasureVoltmeterToFile(
+        CTS3Exception._check_error(_MPuLib.GetAnalyzedMeasureVoltmeterToFile(
             c_uint8(0),
             c_uint32(measurement_type),
             c_uint32(card_type),
@@ -357,7 +323,7 @@ def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
             byref(measurement_count),
             byref(measurements)))
     else:
-        ret = CTS3ErrorCode(_MPuLib.GetAnalyzedMeasureVoltmeterToFile(
+        CTS3Exception._check_error(_MPuLib.GetAnalyzedMeasureVoltmeterToFile(
             c_uint8(0),
             c_uint32(measurement_type),
             c_uint32(card_type),
@@ -366,13 +332,12 @@ def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
             None,
             byref(measurement_count),
             byref(measurements)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     if measurement_count.value:
-        ptr = cast(measurements, POINTER(c_int32 * measurement_count.value))
+        ptr = c_cast(measurements, POINTER(c_int32 * measurement_count.value))
         values = [i for i in ptr.contents]
         if measurement_type == MeasurementType.SCINFC_MEASTYPE_PCD_WAVEFORM:
-            if card_type == TechnologyType.TYPE_A and data_rate == 106:
+            if card_type == TechnologyType.TYPE_A and \
+                    data_rate == DataRate.DATARATE_106KB:
                 t5 = []
                 for i in range(16, 16 + values[15]):
                     t5 += [values[i] / 1e9]
@@ -394,7 +359,8 @@ def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
                         't5': t5,
                         'modulation_index': values[16 + len(t5)] / 1e6,
                         'modulation_depth': values[17 + len(t5)] / 1e6}
-            elif card_type == TechnologyType.TYPE_A and data_rate > 106:
+            elif card_type == TechnologyType.TYPE_A and \
+                    data_rate > DataRate.DATARATE_106KB:
                 return {'t1': values[0] / 1e9,
                         't5': values[1] / 1e9,
                         't6': values[2] / 1e9,
@@ -476,12 +442,10 @@ def MPC_StoreCoeffAlignStandard(measure_type: MeasurementType,
     if not isinstance(measure_type, MeasurementType):
         raise TypeError('measure_type must be an instance of '
                         'MeasurementType IntEnum')
-    ret = CTS3ErrorCode(_MPuLib.MPC_StoreCoeffAlignStandard(
+    CTS3Exception._check_error(_MPuLib.MPC_StoreCoeffAlignStandard(
         c_uint8(0),
         c_uint32(measure_type),
         c_double(coefficient)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 # region Reader frequency measurement
 
@@ -496,35 +460,42 @@ class FrequencyResolution(IntEnum):
     RESOLUTION_AUTO = 5
 
 
+@overload
+def MPC_GetRFFrequency() -> int:
+    ...
+
+
+@overload
 def MPC_GetRFFrequency(resolution: FrequencyResolution,
                        timeout: float) -> int:
+    ...
+
+
+def MPC_GetRFFrequency(resolution=None,  # type: ignore[no-untyped-def]
+                       timeout=None):
     """Performs a carrier frequency measurement
 
     Parameters
     ----------
-    resolution : FrequencyResolution
-        Acquisition resolution
-    timeout : float
-        Acquisition timeout in s
+    resolution : FrequencyResolution, optional
+        Not used
+    timeout : float, optional
+        Not used
 
     Returns
     -------
     int
         Measured frequency in Hz
     """
-    if not isinstance(resolution, FrequencyResolution):
-        raise TypeError('resolution must be an instance of '
-                        'FrequencyResolution IntEnum')
-    timeout_ms = round(timeout * 1e3)
-    _check_limits(c_uint32, timeout_ms, 'timeout')
+    if resolution is not None or timeout is not None:
+        warn("deprecated 'resolution' or 'timeout' parameter",
+             FutureWarning, 2)
     freq = c_uint32()
-    ret = CTS3ErrorCode(_MPuLib.MPC_GetRFFrequency(
+    CTS3Exception._check_error(_MPuLib.MPC_GetRFFrequency(
         c_uint8(0),
-        c_uint32(resolution),
-        c_uint32(timeout_ms),
+        c_uint32(0),
+        c_uint32(0),
         byref(freq)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     return freq.value
 
 # endregion
@@ -533,7 +504,7 @@ def MPC_GetRFFrequency(resolution: FrequencyResolution,
 
 
 def MPC_GetDatarate(card_type: TechnologyType) -> int:
-    """Measures the current data rate
+    """Measures the last received frame data rate
 
     Parameters
     ----------
@@ -549,12 +520,10 @@ def MPC_GetDatarate(card_type: TechnologyType) -> int:
         raise TypeError('card_type must be an instance of '
                         'TechnologyType IntEnum')
     datarate = c_uint32()
-    ret = CTS3ErrorCode(_MPuLib.MPC_GetDatarate(
+    CTS3Exception._check_error(_MPuLib.MPC_GetDatarate(
         c_uint8(0),
         c_uint8(card_type),
         byref(datarate)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     return datarate.value
 
 # endregion
@@ -581,17 +550,15 @@ def MPC_ImpedanceSelfCompensation(connector: MeasurementConnector,
                         'MeasurementConnector IntEnum')
     _check_limits(c_uint8, channel, 'channel')
     if label is None:
-        ret = CTS3ErrorCode(_MPuLib.MPC_ImpedanceSelfCompensation(
+        CTS3Exception._check_error(_MPuLib.MPC_ImpedanceSelfCompensation(
             c_uint8(connector),
             c_uint8(channel),
             None))
     else:
-        ret = CTS3ErrorCode(_MPuLib.MPC_ImpedanceSelfCompensation(
+        CTS3Exception._check_error(_MPuLib.MPC_ImpedanceSelfCompensation(
             c_uint8(connector),
             c_uint8(channel),
             label.encode('ascii')))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 def MPC_ImpedanceLoadCable(label: Optional[str]) -> None:
@@ -603,18 +570,16 @@ def MPC_ImpedanceLoadCable(label: Optional[str]) -> None:
         Compensation identifier
     """
     if label is None:
-        ret = CTS3ErrorCode(_MPuLib.MPC_ImpedanceLoadCable(
+        CTS3Exception._check_error(_MPuLib.MPC_ImpedanceLoadCable(
             c_uint8(0),
             None))
     else:
-        ret = CTS3ErrorCode(_MPuLib.MPC_ImpedanceLoadCable(
+        CTS3Exception._check_error(_MPuLib.MPC_ImpedanceLoadCable(
             c_uint8(0),
             label.encode('ascii')))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
-def MPC_ImpedanceListCables() -> Optional[List[str]]:
+def MPC_ImpedanceListCables() -> List[str]:
     """Lists available cable compensations information
 
     Returns
@@ -623,13 +588,11 @@ def MPC_ImpedanceListCables() -> Optional[List[str]]:
         Compensation identifiers list
     """
     cables_list = create_string_buffer(0xFFFF)
-    ret = CTS3ErrorCode(_MPuLib.MPC_ImpedanceListCables(
+    CTS3Exception._check_error(_MPuLib.MPC_ImpedanceListCables(
         c_uint8(0),
         cables_list))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     list_string = cables_list.value.decode('ascii')
-    return list_string.split(';') if len(list_string) else None
+    return list_string.split(';') if len(list_string) else []
 
 
 def MPC_ImpedanceDeleteCable(label: str) -> None:
@@ -640,15 +603,13 @@ def MPC_ImpedanceDeleteCable(label: str) -> None:
     label : str
         Compensation identifier
     """
-    ret = CTS3ErrorCode(_MPuLib.MPC_ImpedanceDeleteCable(
+    CTS3Exception._check_error(_MPuLib.MPC_ImpedanceDeleteCable(
         c_uint8(0),
         label.encode('ascii')))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
-def MPC_MeasureImpedance(use_cable: bool = True,
-                         average: int = 1) -> Dict[str, Union[float, complex]]:
+def MPC_MeasureImpedance(use_cable: bool = True, average: int = 1) \
+        -> Dict[str, Union[float, complex]]:
     """Performs an impedance measurement
 
     Parameters
@@ -676,7 +637,7 @@ def MPC_MeasureImpedance(use_cable: bool = True,
     inductance = c_double()
     vcc = c_double()
     icc = c_double()
-    ret = CTS3ErrorCode(_MPuLib.MPC_MeasureImpedance(
+    CTS3Exception._check_error(_MPuLib.MPC_MeasureImpedance(
         c_uint8(0),
         c_uint8(1) if use_cable else c_uint8(0),
         c_uint32(average),
@@ -687,8 +648,6 @@ def MPC_MeasureImpedance(use_cable: bool = True,
         byref(inductance),
         byref(vcc),
         byref(icc)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     return {'impedance': complex(real_part.value, imaginary_part.value),
             'resistance': resistance.value,
             'capacitance': capacitance.value,
@@ -713,7 +672,8 @@ def MPC_ResonanceFrequency(method: ResonanceMethod,
                            step: float,
                            freq_min: float,
                            freq_max: float,
-                           average: int = 1) -> Dict[str, Union[int, float]]:
+                           average: int = 1) \
+        -> Dict[str, Union[int, float]]:
     """Performs a resonance frequency measurement
 
     Parameters
@@ -751,7 +711,7 @@ def MPC_ResonanceFrequency(method: ResonanceMethod,
     _check_limits(c_uint32, average, 'average')
     freq = c_uint32()
     q = c_uint32()
-    ret = CTS3ErrorCode(_MPuLib.MPC_ResonanceFrequencyVS(
+    CTS3Exception._check_error(_MPuLib.MPC_ResonanceFrequencyVS(
         c_uint8(0),
         c_uint8(method),
         c_int32(power_dbm_int),
@@ -761,8 +721,6 @@ def MPC_ResonanceFrequency(method: ResonanceMethod,
         c_uint32(freq_max_Hz),
         byref(freq),
         byref(q)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     return {'resonance_frequency': freq.value,
             'q_factor': float(q.value) / 1e1}
 
@@ -793,15 +751,13 @@ def MPC_GetMeasureResFreq(measure_type: ResFreqMeasureType =
                         'ResFreqMeasureType IntEnum')
     measurement_count = c_uint32()
     measurements = c_void_p()
-    ret = CTS3ErrorCode(_MPuLib.MPC_GetMeasureResFreq(
+    CTS3Exception._check_error(_MPuLib.MPC_GetMeasureResFreq(
         c_uint8(0),
         byref(measurement_count),
         byref(measurements),
         c_int32(measure_type)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     if measurement_count.value:
-        ptr = cast(measurements, POINTER(c_double * measurement_count.value))
+        ptr = c_cast(measurements, POINTER(c_double * measurement_count.value))
         return [i for i in ptr.contents]
     else:
         return []
@@ -840,15 +796,13 @@ def MPC_S11StartMeasurement(frequency_min: float,
     power_dbm_int = round(power_dbm)
     _check_limits(c_int32, power_dbm_int, 'power_dbm')
     _check_limits(c_uint32, average, 'average')
-    ret = CTS3ErrorCode(_MPuLib.MPC_S11StartMeasurement(
+    CTS3Exception._check_error(_MPuLib.MPC_S11StartMeasurement(
         c_uint8(0),
         c_uint32(freq_min_Hz),
         c_uint32(freq_max_Hz),
         c_uint32(step_Hz),
         c_int32(power_dbm_int),
         c_uint32(average)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
 
 
 @unique
@@ -878,15 +832,13 @@ def MPC_GetMeasureS11(measure_type: S11MeasureType =
                         'S11MeasureType IntEnum')
     measurement_count = c_uint32()
     measurements = c_void_p()
-    ret = CTS3ErrorCode(_MPuLib.MPC_GetMeasureS11(
+    CTS3Exception._check_error(_MPuLib.MPC_GetMeasureS11(
         c_uint8(0),
         byref(measurement_count),
         byref(measurements),
         c_int32(measure_type)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     if measurement_count.value:
-        ptr = cast(measurements, POINTER(c_double * measurement_count.value))
+        ptr = c_cast(measurements, POINTER(c_double * measurement_count.value))
         return [i for i in ptr.contents]
     else:
         return []
@@ -924,7 +876,7 @@ def MPC_GetS11(frequency: float = 0.0) -> Dict[str, Union[float, complex]]:
     real_at_frequency = c_double()
     imaginary_at_frequency = c_double()
     module_at_frequency = c_double()
-    ret = CTS3ErrorCode(_MPuLib.MPC_GetS11(
+    ret = _MPuLib.MPC_GetS11(
         c_uint8(0),
         c_uint32(freq_Hz),
         byref(dbm_at_min),
@@ -935,15 +887,14 @@ def MPC_GetS11(frequency: float = 0.0) -> Dict[str, Union[float, complex]]:
         byref(dbm_at_frequency),
         byref(real_at_frequency),
         byref(imaginary_at_frequency),
-        byref(module_at_frequency)))
-    if ret == CTS3ErrorCode.ERR_RESONANCE_FREQUENCY_MEASUREMENT and \
+        byref(module_at_frequency))
+    if ret == CTS3ErrorCode.ERR_RESONANCE_FREQUENCY_MEASUREMENT.value and \
             frequency > 0.0:
         return {'dbm_at_frequency': dbm_at_frequency.value,
                 'impedance_at_frequency': complex(real_at_frequency.value,
                                                   imaginary_at_frequency.value)
                 }
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
+    CTS3Exception._check_error(ret)
     if frequency > 0.0:
         return {'dbm_at_min': dbm_at_min.value,
                 'frequency_at_min': frequency_at_min.value,
@@ -988,12 +939,10 @@ def MPC_GetRFField(coil: CalibrationCoil =
     if not isinstance(coil, CalibrationCoil):
         raise TypeError('coil must be an instance of CalibrationCoil IntEnum')
     voltage = c_uint32()
-    ret = CTS3ErrorCode(_MPuLib.MPC_GetRFField(
+    CTS3Exception._check_error(_MPuLib.MPC_GetRFField(
         c_uint8(0),
         c_uint32(coil),
         byref(voltage)))
-    if ret != CTS3ErrorCode.RET_OK:
-        raise CTS3Exception(ret)
     return voltage.value / 1e3
 
 # endregion
